==> musashi_text-0.1.tar.gz: musashi_text-0.1/musashi_text/textdialog.h <==
#ifndef TEXTDIALOG_H
#define TEXTDIALOG_H
/**********************************************************************

  textdialog.h

  Author    : fuja2 ( fuja2 at bj8 dot so-net dot ne dot jp )
  created at: Sun. Apr.11  23:59:03 JST 2004
  edited  at: 

  Copyright (C) 2004  Kazuo Sonobe, All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

**********************************************************************/
#include <qdialog.h>
#include <qtextedit.h>
#include <qlabel.h>

#include "soolist.h"

class QHBoxLayout;
class QPushButton;
class QTable;
class QVBoxLayout;


class textDialog: public QDialog
{
    Q_OBJECT
public:
    textDialog( QString filename , QStringList wordlist );
    ~textDialog();

public slots:

protected slots:
    void accept();

private:
    QLabel*    fileLabel;
    QTextEdit* textedit;
    QPushButton *closeButton;

protected:
    QVBoxLayout *tableButtonBox;
    QHBoxLayout *buttonBox;

private:

};

#endif

==> musashi_text-0.2.tar.gz: musashi_text-0.2/musashi_text/textdialog.h <==
#ifndef TEXTDIALOG_H
#define TEXTDIALOG_H
/**********************************************************************

  textdialog.h

  Author    : fuja2 ( fuja2 at bj8 dot so-net dot ne dot jp )
  created at: Sun. Apr.11  23:59:03 JST 2004
  edited  at: 

  Copyright (C) 2004  Kazuo Sonobe, All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

**********************************************************************/
#include <qdialog.h>
#include <qtextedit.h>
#include <qlabel.h>

#include "soolist.h"

class QHBoxLayout;
class QPushButton;
class QTable;
class QVBoxLayout;


class textDialog: public QDialog
{
    Q_OBJECT
public:
    textDialog( QString filename , QStringList wordlist , QWidget* parent );
    //~textDialog();

public slots:

protected slots:
    void accept();

private:
    QLabel*    fileLabel;
    QTextEdit* textedit;
    QPushButton *closeButton;

protected:
    QVBoxLayout *tableButtonBox;
    QHBoxLayout *buttonBox;

private:

};

#endif
